![unimport](https://raw.githubusercontent.com/hakancelikdev/unimport/main/docs/assets/logo/unimport.png)

**A linter, formatter for finding and removing unused import statements.**

https://user-images.githubusercontent.com/19157033/173917900-a3e99b84-bb53-455c-85ec-91d7e696b4c6.mp4

[![pre-commit.ci status](https://results.pre-commit.ci/badge/github/hakancelikdev/unimport/main.svg)](https://results.pre-commit.ci/latest/github/hakancelikdev/unimport/main)
![test](https://github.com/hakancelikdev/unimport/workflows/Test/badge.svg)

[![Pypi](https://img.shields.io/pypi/v/unimport)](https://pypi.org/project/unimport/)
![PyPI - Python Version](https://img.shields.io/pypi/pyversions/unimport)
[![Downloads](https://static.pepy.tech/personalized-badge/unimport?period=total&units=international_system&left_color=grey&right_color=red&left_text=downloads)](https://pepy.tech/project/unimport)
[![License](https://img.shields.io/github/license/hakancelikdev/unimport.svg)](https://github.com/hakancelikdev/unimport/blob/main/LICENSE)

[![Forks](https://img.shields.io/github/forks/hakancelikdev/unimport)](https://github.com/hakancelikdev/unimport/fork)
[![Issues](https://img.shields.io/github/issues/hakancelikdev/unimport)](https://github.com/hakancelikdev/unimport/issues)
[![Stars](https://img.shields.io/github/stars/hakancelikdev/unimport)](https://github.com/hakancelikdev/unimport/stargazers)

[![Codecov](https://codecov.io/gh/hakancelikdev/unimport/branch/main/graph/badge.svg)](https://codecov.io/gh/hakancelikdev/unimport)
[![Contributors](https://img.shields.io/github/contributors/hakancelikdev/unimport)](https://github.com/hakancelikdev/unimport/graphs/contributors)
[![Last Commit](https://img.shields.io/github/last-commit/hakancelikdev/unimport.svg)](https://github.com/hakancelikdev/unimport/commits/main)

For more information see: https://unimport.hakancelik.dev/

Try it out now using the Unimport Playground,
https://playground-unimport.hakancelik.dev/
